/**
 * Representation of an arsonist. The arsonist is setting the grass on fire. If
 * the boy enters the cell with the arsonist he will be displaced.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Arsonist extends Baddie {

	public Arsonist(int c, int r, int d) {
		super(c, r, d);
		this.numberOfPollutions = 0;
		this.maxNumberOfPollutions = 8;
		this.cycleDuration = 100;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Baddie#pollute()
	 */
	@Override
	protected void pollute(WasteWorld world) {
		if (this.numberOfPollutions < this.maxNumberOfPollutions
				&& !this.world.cellOccupied(this.oldCol, this.oldRow)) {
			// set the grass on fire
			this.world.checkAndChangeItem(this.oldCol, this.oldRow, new Fire(
					world.getLevel().getWorldFilter()));
			this.numberOfPollutions++;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#handleCollisionAfterScrolling(WasteWorld, int, int)
	 */
	@Override
	public void handleCollisionAfterScrolling(WasteWorld world, int col, int row) {
		super.handleCollisionAfterScrolling(world, col, row);
		// extinguisher in storage?
		if (Storage.getStorage().containsItem(Item.FIRE_EXTINGUISHER)) {
			if (Fire.getNumberOfFireAndArsonists(world) == 0) {

				// no more fire -> remove extinguishers from the storage
				Storage.getStorage().removeItems(Item.FIRE_EXTINGUISHER);
			}
		}
	}
}
