import greenfoot.GreenfootImage;

/**
 * Representation of a bike. A car can be replaced by a bike.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Bike extends Item {

	// shared by all bikes
	final static GreenfootImage imageLeft = new GreenfootImage("bike-left.png");
	final static GreenfootImage imageRight = new GreenfootImage(
			"bike-right.png");

	private int number;
	private boolean left;
	private boolean changed;

	public Bike() {
		this(true);
	}

	public Bike(boolean left) {
		super(Item.CAR_BIKE);
		this.number = 0;
		this.changed = false;
		this.left = left;
		if (left) {
			this.setImage(Bike.imageLeft);
		} else {
			this.setImage(Bike.imageRight);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		return true; // ca be entered by the boy
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c + 1) * cellSize, (r + 1) * cellSize);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#handleCollisionAfterScrolling(WasteWorld, int, int)
	 */
	@Override
	public void handleCollisionAfterScrolling(WasteWorld world, int col, int row) {
		if (!this.changed && !Storage.getStorage().isFull()) {
			Sounds.pickup();
			Storage.getStorage().addItem(this); // add the bike to the storage
			world.removeItem(col, row); // remove it from the world
		}
	}

	/**
	 * a car has been replaced by this bike
	 */
	public void setChanged() {
		this.changed = true;
	}

	/* (non-Javadoc)
	 * @see Item#act(WasteWorld, int, int)
	 */
	@Override
	public void act(WasteWorld world, int col, int row) {
		if (!this.changed) {
			return;
		}
		
		// moving in the world
		this.number++;
		if (this.number % 5 == 0) {
			this.move(world, col, row);
		}
	}

	private void move(WasteWorld world, int col, int row) {
		if (this.freeAhead(world, col, row)) {
			this.moveAhead(world, col, row);
		} else {
			this.turn();
		}
	}

	private void turn() {
		this.left = !this.left;
		if (this.left) {
			this.setImage(Bike.imageLeft);
		} else {
			this.setImage(Bike.imageRight);
		}
	}

	private boolean freeAhead(WasteWorld world, int col, int row) {
		if (this.left) {
			return !world.cellOccupied(col - 1, row);
		} else {
			return !world.cellOccupied(col + 1, row);
		}
	}

	private void moveAhead(WasteWorld world, int col, int row) {
		world.removeItem(col, row);
		if (this.left) {
			world.changeItem(col - 1, row, this);
		} else {
			world.changeItem(col + 1, row, this);
		}
	}
}
