import greenfoot.Actor;
import greenfoot.GreenfootImage;

/**
 * Representation of the boy. His main task is to find, collect and dispose of
 * the waste in the waste world.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Boy extends Actor {
	public final static int RIGHT = 0;
	public final static int DOWN = 1;
	public final static int LEFT = 2;
	public final static int UP = 3;

	final static int MAX_SICKNESS = 50;

	private int col;
	private int row;
	private int direction;
	private WasteWorld world;
	private int sickness;

	private GreenfootImage[][] imgs;

	/**
	 * @param w
	 *            the waste world
	 * @param c
	 *            the column
	 * @param r
	 *            the row
	 * @param d
	 *            the direction (see constants above)
	 */
	public Boy(WasteWorld w, int c, int r, int d) {
		this.imgs = new GreenfootImage[4][3];
		for (int i = 0; i < 4; i++) {
			for (int j = 0; j < 3; j++) {
				this.imgs[i][j] = new GreenfootImage("creature-" + i + "-" + j
						+ ".png");
			}
		}

		this.world = w;
		this.col = c;
		this.row = r;
		this.setDirection(d);
		this.sickness = 0;
	}

	/**
	 * reset the position of the boy
	 * 
	 * @param c
	 *            the column
	 * @param r
	 *            the row
	 * @param d
	 *            the direction (see constants above)
	 */
	public void reset(int c, int r, int d) {
		this.col = c;
		this.row = r;
		this.setDirection(d);
		this.sickness = 0;
	}

	public int getCol() {
		return this.col;
	}

	public int getRow() {
		return this.row;
	}

	public int getDirection() {
		return this.direction;
	}

	public void setDirection(int d) {
		this.direction = d;
		this.setImage(this.imgs[this.direction][0]);
	}

	public void setDiff(int diff) {
		this.setImage(this.imgs[this.direction][diff]);
	}

	public boolean canMove(int direction) {
		switch (direction) {
		case RIGHT:
			return this.world.cellAccessible(this.col + 1, this.row);
		case DOWN:
			return this.world.cellAccessible(this.col, this.row + 1);
		case LEFT:
			return this.world.cellAccessible(this.col - 1, this.row);
		default:
			return this.world.cellAccessible(this.col, this.row - 1);
		}
	}

	public boolean right() {
		this.setDirection(Boy.RIGHT);
		if (this.world.cellAccessible(this.col + 1, this.row)) {
			this.col = this.col + 1;
			return true;
		} else {
			return false;
		}
	}

	public boolean left() {
		this.setDirection(Boy.LEFT);
		if (this.world.cellAccessible(this.col - 1, this.row)) {
			this.col = this.col - 1;
			return true;
		} else {
			return false;
		}
	}

	public boolean up() {
		this.setDirection(Boy.UP);
		if (this.world.cellAccessible(this.col, this.row - 1)) {
			this.row = this.row - 1;
			return true;
		} else {
			return false;
		}
	}

	public boolean down() {
		this.setDirection(Boy.DOWN);
		if (this.world.cellAccessible(this.col, this.row + 1)) {
			this.row = this.row + 1;
			return true;
		} else {
			return false;
		}
	}

	public void setSick() {
		this.sickness = Boy.MAX_SICKNESS;
	}

	public boolean isSick() {
		this.sickness--;
		return this.sickness > 0;
	}

	public GreenfootImage getImage(int direction) {
		return this.imgs[direction][0];
	}
}
