import greenfoot.GreenfootImage;

/**
 * Representation of a car. A car can be replaced by a bike.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Car extends Item {

	final static int BONUS = 40; // if a car will be replaced by a bike

	// shared by all cars
	final static GreenfootImage imageLeft = new GreenfootImage("car-left.png");
	final static GreenfootImage imageRight = new GreenfootImage("car-right.png");

	private int number;
	private boolean left;

	public Car() {
		this(true);
	}

	public Car(boolean left) {
		super(Item.CAR_BIKE);
		this.number = 0;
		this.left = left;
		if (left) {
			this.setImage(Car.imageLeft);
		} else {
			this.setImage(Car.imageRight);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		return Storage.getStorage().containsItem(this.getType());
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c + 1) * cellSize, (r + 1) * cellSize);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#handleCollisionAfterScrolling(WasteWorld, int, int)
	 */
	@Override
	public void handleCollisionAfterScrolling(WasteWorld world, int col, int row) {
		Item bike = Storage.getStorage().removeOneItem(this.getType());
		if (bike != null) {
			Boy boy = world.getBoy();
			world.changeItem(col, row, bike); // remove car, put bike
			((Bike) bike).setChanged();
			Sounds.conservationBonus();
			if (world.getLevel().getWorldFilter() != null) {
				world.getLevel().getWorldFilter().reduceTransparency(); // reduce the smog
			}
			ConservationBonus bonus = new ConservationBonus(Car.BONUS);
			world.addObject(bonus, boy.getX(), boy.getY()
					- boy.getImage().getHeight());
			Points.getPoints().incrPoints(Car.BONUS);
			world.repaint();
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#act(WasteWorld, int, int)
	 */
	@Override
	public void act(WasteWorld world, int col, int row) {
		this.number++;
		if (this.number % 5 == 0) {
			this.move(world, col, row);
		}
	}

	private void move(WasteWorld world, int col, int row) {
		if (this.freeAhead(world, col, row)) {
			this.moveAhead(world, col, row);
		} else {
			this.turn();
		}
	}

	private void turn() {
		this.left = !this.left;
		if (this.left) {
			this.setImage(Car.imageLeft);
		} else {
			this.setImage(Car.imageRight);
		}
	}

	private boolean freeAhead(WasteWorld world, int col, int row) {
		if (this.left) {
			return !world.cellOccupied(col - 1, row);
		} else {
			return !world.cellOccupied(col + 1, row);
		}
	}

	private void moveAhead(WasteWorld world, int col, int row) {
		world.removeItem(col, row);
		if (this.left) {
			world.changeItem(col - 1, row, this);
		} else {
			world.changeItem(col + 1, row, this);
		}
	}
}
