import greenfoot.GreenfootImage;

/**
 * Representation of a coal-burning power plant. By entering a coal-burning
 * power plant it will be replaced by a solar collector.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Coal extends Item {

	final static int BONUS = 30; // bonus for replacing it by a solar collector

	// shared by all objects
	private static GreenfootImage img = new GreenfootImage("coal.png");

	public Coal() {
		super(Item.COAL_SOLAR);
		this.setImage(Coal.img);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		return true; // can be entered by the boy
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c + 1) * cellSize, (r + 1) * cellSize);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#handleCollisionAfterScrolling(WasteWorld, int, int)
	 */
	@Override
	public void handleCollisionAfterScrolling(WasteWorld world, int col, int row) {
		Boy boy = world.getBoy();
		world.changeItem(col, row, new Solar()); // remove coal-fired power
		// station, put solar collector
		if (world.getLevel().getWorldFilter() != null) {
			// reduce the gray filter
			world.getLevel().getWorldFilter().reduceTransparency();
		}
		Sounds.conservationBonus();
		ConservationBonus bonus = new ConservationBonus(Coal.BONUS);
		world.addObject(bonus, boy.getX(), boy.getY()
				- boy.getImage().getHeight());
		Points.getPoints().incrPoints(Coal.BONUS);
		world.repaint();
	}
}
