import greenfoot.Greenfoot;
import greenfoot.GreenfootImage;

/**
 * Representation of a door. Can be opened using a key.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Door extends Item {

	// shared by all objects
	private static GreenfootImage img = new GreenfootImage("door.png");

	public Door() {
		super(Item.DOOR_KEY);
		this.setImage(Door.img);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		// can be entered by the boy if a key is in the storage
		return Storage.getStorage().containsItem(this.getType());
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c + 1) * cellSize, r * cellSize);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#handleCollision(WasteWorld, int, int)
	 */
	@Override
	public void handleCollision(WasteWorld world, int col, int row) {
		Item key = Storage.getStorage().removeOneItem(this.getType());
		// a key will be removed from the storage
		if (key != null) {
			Sounds.openDoor();
			Greenfoot.delay(5);
			world.removeItem(col, row); // remove/open door
		}
	}
}
