import greenfoot.GreenfootImage;

/**
 * representation of a dustbin
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public abstract class Dustbin extends Item {

	public Dustbin(int type) {
		super(type);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		return true; // cannot be entered by the boy
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c + 1) * cellSize, r * cellSize);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#handleCollision(WasteWorld, int, int)
	 */
	@Override
	public void handleCollision(WasteWorld world, int col, int row) {
		Item[] wasteItems = Storage.getStorage().removeItems(this.getType());
		if (wasteItems.length > 0) {
			Points.getPoints().incrPoints(wasteItems.length * 10);
			this.throwIntoSound();
			this.checkLevelReady(world);
		}
	}

	/**
	 * Checks whether the level has been completed. A level has been completed
	 * if the storage is empty and there is no more waste in the waste world
	 * 
	 * @param world
	 *            waste world
	 */
	private void checkLevelReady(WasteWorld world) {
		if (!Storage.getStorage().containsWaste()
				&& Rest.getRest().getRestNumber() == 0) {
			world.getLevel().setFinished();
			if (Level.existsNotFinishedLevel()) { // further levels?
				world.setLevelFinished();
			} else { // all levels completed
				world.setGameOver(true);
			}
		}
	}

	/**
	 * sound for throwing an item into a dustbin
	 */
	public void throwIntoSound() {
		Sounds.throwInto();
	}

}
