import greenfoot.Actor;
import greenfoot.GreenfootImage;

import java.awt.Color;

/**
 * representation of a filter
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public abstract class Filter extends Actor {

	protected int transparency;
	protected int reduction;
	protected int maxTransparency;
	protected GreenfootImage image;

	public Filter(int number, int startTrans, Color color, int width, int height) {
		this.reduction = startTrans / number; // calculate the reduction factor
		this.image = new GreenfootImage(width, height);
		this.image.setColor(color);
		this.image.fill();
		this.transparency = startTrans;
		this.maxTransparency = startTrans;
		this.image.setTransparency(this.transparency);
		this.setImage(this.image);
	}

	public Filter(int max, Color color, int width, int height) {
		this.reduction = 0;
		this.maxTransparency = max;
		this.image = new GreenfootImage(width, height);
		this.image.setColor(color);
		this.image.fill();
		this.transparency = 0;
		this.image.setTransparency(this.transparency);
		this.setImage(this.image);
	}

	/**
	 * reduce the transparency by the reduction factor
	 */
	public void reduceTransparency() {
		this.transparency = this.transparency - this.reduction;
		if (this.transparency < 0) {
			this.transparency = 0;
		}
		this.image.setTransparency(this.transparency);
	}

	/**
	 * reduce the transparency by a certain factor
	 */
	public void reduceTransparency(int r) {
		this.transparency = this.transparency - r;
		if (this.transparency < 0) {
			this.transparency = 0;
		}
		this.image.setTransparency(this.transparency);
	}

	/**
	 * reduce the transparency by a certain factor
	 */
	public void increaseTransparency(int r) {
		this.transparency = this.transparency + r;
		if (this.transparency > this.maxTransparency) {
			this.transparency = this.maxTransparency;
		}
		this.image.setTransparency(this.transparency);
	}

	/**
	 * sets the transparency
	 */
	public void setTransparency(int t) {
		this.transparency = t;
		if (this.transparency < 0) {
			this.transparency = 0;
		} else if (this.transparency > this.maxTransparency) {
			this.transparency = this.maxTransparency;
		}
		this.image.setTransparency(this.transparency);
	}

	public void setMin() {
		this.transparency = 0;
		this.image.setTransparency(this.transparency);
	}

	public void setMax() {
		this.transparency = this.maxTransparency;
		this.image.setTransparency(this.transparency);
	}
}
