import greenfoot.GreenfootImage;

/**
 * representation of a fire
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Fire extends Item {

	// shared by all objects
	private static GreenfootImage img = new GreenfootImage("fire.png");

	private static int TRANSPARENCY_FACTOR = 10;

	final static int WAIT_NUMBER = 120;
	final static int BONUS = 5; // bonus points for extinguishing a fire

	static int numberOfFire = 0;

	private int number;

	public static void staticInit() {
		Fire.numberOfFire = 0;
	}

	public Fire() {
		super(Item.FIRE_EXTINGUISHER);
		this.setImage(Fire.img);
		this.number = 0;
	}

	public Fire(Filter filter) {
		super(Item.FIRE_EXTINGUISHER);
		this.setImage(Fire.img);
		this.number = 0;
		Fire.numberOfFire++;
		filter.setTransparency(Fire.numberOfFire * Fire.TRANSPARENCY_FACTOR);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		// only with an extinguisher in the storage
		return Storage.getStorage().containsItem(this.getType());
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c + 1) * cellSize, (r + 1) * cellSize);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#handleCollision(WasteWorld, int, int)
	 */
	@Override
	public void handleCollision(WasteWorld world, int col, int row) {
		// extinguisher in storage?
		if (Storage.getStorage().containsItem(this.getType())) {
			Boy boy = world.getBoy();
			world.removeItem(col, row); // remove fire
			Fire.numberOfFire--;
			world.getLevel().getWorldFilter().setTransparency(
					Fire.numberOfFire * Fire.TRANSPARENCY_FACTOR);
			// put burned ground
			// world.changeItem(col, row, new BurnedGround());
			if (Fire.getNumberOfFireAndArsonists(world) == 0) {
				// no more fire -> remove extinguishers from the storage
				Storage.getStorage().removeItems(this.getType());
			}
			Sounds.conservationBonus();
			ConservationBonus bonus = new ConservationBonus(Fire.BONUS);
			world.addObject(bonus, boy.getX(), boy.getY()
					- boy.getImage().getHeight());
			Points.getPoints().incrPoints(Fire.BONUS);
			this.number = Fire.WAIT_NUMBER + 1;
			world.repaint();
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#act(WasteWorld, int, int)
	 */
	@Override
	public void act(WasteWorld world, int col, int row) {
		this.number++;
		if (this.number == Fire.WAIT_NUMBER) {
			// spreading of fire
			Filter filter = world.getLevel().getWorldFilter();
			Fire fire = new Fire();
			if (world.checkAndChangeItem(col + 1, row, fire)) {
				Fire.numberOfFire++;
				filter.setTransparency(Fire.numberOfFire
						* Fire.TRANSPARENCY_FACTOR);
			}
			fire = new Fire();
			if (world.checkAndChangeItem(col - 1, row, fire)) {
				Fire.numberOfFire++;
				filter.setTransparency(Fire.numberOfFire
						* Fire.TRANSPARENCY_FACTOR);
			}
			fire = new Fire();
			if (world.checkAndChangeItem(col, row + 1, fire)) {
				Fire.numberOfFire++;
				filter.setTransparency(Fire.numberOfFire
						* Fire.TRANSPARENCY_FACTOR);
			}
			fire = new Fire();
			if (world.checkAndChangeItem(col, row - 1, fire)) {
				Fire.numberOfFire++;
				filter.setTransparency(Fire.numberOfFire
						* Fire.TRANSPARENCY_FACTOR);
			}
		}
	}

	static int getNumberOfFireAndArsonists(WasteWorld world) {
		int number = 0;
		Item[][] items = world.getItems();
		for (int c = 0; c < WasteWorld.COLS; c++) {
			for (int r = 0; r < WasteWorld.ROWS; r++) {
				if (items[c][r] != null
						&& (items[c][r] instanceof Fire || items[c][r] instanceof Arsonist)) {
					number++;
				}
			}
		}
		return number;
	}
}
