import greenfoot.Actor;
import greenfoot.GreenfootImage;

/**
 * Super class of all items. Items can be put into the waste world.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public abstract class Item extends Actor {

	// constants declaring the type of the item
	public final static int NO_TYPE = 0;

	// Waste between 1 and 5
	public final static int MIN_WASTE_TYPE = 1;
	public final static int PAPER = 1;
	public final static int GLASS = 2;
	public final static int METAL = 3;
	public final static int REST = 4;
	public final static int BIO = 5;
	public final static int MAX_WASTE_TYPE = 5;

	// declaring pairs
	public final static int DOOR_KEY = 10;
	public final static int CAR_BIKE = 11;
	public final static int PITFALL_LADDER = 12;
	public final static int NUCLEAR_WIND = 13;
	public final static int COAL_SOLAR = 14;
	public final static int STUMP_TREE = 15;
	public final static int FIRE_EXTINGUISHER = 16;

	protected int type;

	public Item() {
		this.type = Item.NO_TYPE;
	}

	public Item(int t) {
		this.type = t;
	}

	public int getType() {
		return this.type;
	}

	/**
	 * checks whether the item is accessible
	 * 
	 * @param world
	 *            the current world
	 * @param col
	 *            the column of the item in the world
	 * @param row
	 *            the row of the item in the world
	 * @return true, if the item is accessible
	 */
	public abstract boolean isAccessible(WasteWorld world, int col, int row);

	/**
	 * draws the image of the item into the greenfoot image
	 * 
	 * @param img
	 *            the greenfoot image into which the item image should be drawn
	 * @param col
	 *            the column of the item
	 * @param row
	 *            the row of the item
	 * @param cellSize
	 *            the size of a cell
	 */
	public abstract void draw(GreenfootImage img, int col, int row, int cellSize);

	/**
	 * This act-method is called explicitly from the act-method of the waste
	 * world. It should be used by items instead of the greenfoot act-method.
	 * 
	 * @param world
	 *            the current world
	 * @param col
	 *            the column of the item in the world
	 * @param row
	 *            the row of the item in the world
	 */
	public void act(WasteWorld world, int col, int row) {
	}

	/**
	 * This method is called in case of a collision between the boy and this
	 * item.
	 * 
	 * @param world
	 *            the current world
	 * @param col
	 *            the column of the item in the world
	 * @param row
	 *            the row of the item in the world
	 */
	public void handleCollision(WasteWorld world, int col, int row) {
	}

	/**
	 * This method is called in case of a collision between between the boy and
	 * this item. It is called prior to the next move (see waste world).
	 * 
	 * @param world
	 *            the current world
	 * @param col
	 *            the column of the item in the world
	 * @param row
	 *            the row of the item in the world
	 */
	public void handleCollisionBeforeMove(WasteWorld world, int col, int row) {
	}

	/**
	 * This method is called in case of a collision between the boy and this
	 * item. It is called after scrolling (see waste world).
	 * 
	 * @param world
	 *            the current world
	 * @param col
	 *            the column of the item in the world
	 * @param row
	 *            the row of the item in the world
	 */
	public void handleCollisionAfterScrolling(WasteWorld world, int col, int row) {
	}

}
