import greenfoot.Greenfoot;
import greenfoot.GreenfootImage;

/**
 * representation of level 7 (waste and arson)
 * 
 * Task: Find, collect and dispose of the waste!
 * 
 * Additional task: Caution! A baddie is setting the grass on fire. Find the
 * arsonist, stop him and extinguish the fire!
 * 
 * Notice: this level contains pitfalls and ladders/bridges
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Level7 extends Level {

	public Level7() {
		super("level7.png", new SelectionItem(7, "level7selection.png"));
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Level#createLevel(Item[][])
	 */
	@Override
	public void createLevel(Item[][] items) {
		this.numberOfWaste = 0;
		this.cellFilter = null; // no cell filter
		this.worldFilter = new FireFilter();

		// empty all cells
		for (int c = 0; c < items.length; c++) {
			for (int r = 0; r < items[c].length; r++) {
				items[c][r] = null;
			}
		}

		// place walls and trees

		createPattern(items, 2, 2);
		createPattern(items, 2, 10);
		createPattern(items, 2, 18);
		createPattern(items, 16, 2);
		createPattern(items, 16, 10);

		items[14][0] = new Wall();
		items[14][1] = new Wall();
		items[14][2] = new Wall();
		items[14][3] = new Wall();
		items[14][4] = new Wall();
		items[14][7] = new Wall();
		items[14][8] = new Wall();
		items[14][9] = new Wall();
		items[14][10] = new Wall();
		items[14][11] = new Wall();
		items[14][12] = new Wall();
		items[14][15] = new Wall();
		items[14][16] = new Wall();
		items[14][17] = new Wall();
		items[14][18] = new Wall();
		items[14][19] = new Wall();
		items[14][20] = new Wall();

		items[22][18] = new Wall();
		items[23][18] = new Wall();

		items[25][8] = new Wall();
		items[26][8] = new Wall();
		items[27][8] = new Wall();
		items[28][8] = new Wall();
		items[29][8] = new Wall();
		items[30][8] = new Wall();
		items[31][8] = new Wall();
		items[32][8] = new Wall();
		items[34][8] = new Wall();

		items[31][13] = new Wall();
		items[32][13] = new Wall();
		items[33][13] = new Wall();
		items[34][13] = new Wall();

		items[29][19] = new Wall();
		items[29][20] = new Wall();
		items[29][21] = new Wall();
		items[28][21] = new Wall();
		items[30][21] = new Wall();

		// place trees

		items[22][19] = new Tree();
		items[23][19] = new Tree();

		items[31][14] = new Tree();
		items[32][14] = new Tree();
		items[33][14] = new Tree();
		items[34][14] = new Tree();

		items[28][22] = new Tree();
		items[29][22] = new Tree();
		items[30][22] = new Tree();

		// place one extinguisher

		int r = Greenfoot.getRandomNumber(3);
		switch (r) {
		case 0:
			items[6][4] = new Extinguisher();
			break;
		case 1:
			items[6][12] = new Extinguisher();
			break;
		default:
			items[6][20] = new Extinguisher();
			break;
		}

		// place two fire

		r = Greenfoot.getRandomNumber(3);
		switch (r) {
		case 0:
			items[8][4] = new Fire(worldFilter);
			items[27][17] = new Fire(worldFilter);
			break;
		case 1:
			items[8][12] = new Fire(worldFilter);
			items[30][17] = new Fire(worldFilter);
			break;
		default:
			items[8][20] = new Fire(worldFilter);
			items[33][23] = new Fire(worldFilter);
			break;
		}

		// place one arsonist

		r = Greenfoot.getRandomNumber(3);
		switch (r) {
		case 0:
			items[30][4] = new Arsonist(30, 4, Arsonist.RIGHT);
			break;
		case 1:
			items[29][10] = new Arsonist(29, 10, Arsonist.DOWN);
			break;
		default:
			items[25][20] = new Arsonist(25, 20, Arsonist.LEFT);
			break;
		}

		// place dustbins

		items[6][11] = new DustbinPaper();
		items[6][3] = new DustbinMetal();
		items[20][3] = new DustbinGlass();
		items[20][11] = new DustbinRest();
		items[6][19] = new DustbinBio();

		// place waste

		for (int i = 0; i < 4; i++) {
			Position pos = this.getFreeCell(items);
			items[pos.getCol()][pos.getRow()] = new WastePaper();
			this.numberOfWaste++;
		}

		for (int i = 0; i < 4; i++) {
			Position pos = this.getFreeCell(items);
			items[pos.getCol()][pos.getRow()] = new WasteMetal();
			this.numberOfWaste++;
		}

		for (int i = 0; i < 4; i++) {
			Position pos = this.getFreeCell(items);
			items[pos.getCol()][pos.getRow()] = new WasteGlass();
			this.numberOfWaste++;
		}

		for (int i = 0; i < 4; i++) {
			Position pos = this.getFreeCell(items);
			items[pos.getCol()][pos.getRow()] = new WasteRest();
			this.numberOfWaste++;
		}

		for (int i = 0; i < 4; i++) {
			Position pos = this.getFreeCell(items);
			items[pos.getCol()][pos.getRow()] = new WasteBio();
			this.numberOfWaste++;
		}

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Level#getSeconds()
	 */
	@Override
	public int getSeconds() {
		return 200;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Level#drawHelp(greenfoot.GreenfootImage)
	 */
	@Override
	public void drawHelp(GreenfootImage image) {
		image.drawString("Level 7 (waste and arson): ", 20, 50);
		image.drawString("Task: Find, collect and dispose of the waste!", 20,
				100);
		image.drawString("Additional task:", 20, 150);
		image.drawString("Caution! A baddie is setting the grass on fire.", 20,
				200);
		image.drawString("Find the arsonist, stop him and", 20, 250);
		image.drawString("extinguish the fire!", 20, 300);

	}

	private void createPattern(Item[][] items, int startCol, int startRow) {
		for (int i = 0; i < 11; i++) {
			items[startCol + i][startRow] = new Wall();
			items[startCol + i][startRow + 4] = new Wall();
			items[startCol + i][startRow + 5] = new Tree();
		}
		items[startCol + 2][startRow + 2] = new Wall();
		items[startCol + 3][startRow + 2] = new Wall();
		items[startCol + 5][startRow + 2] = new Wall();
		items[startCol + 8][startRow + 2] = new Wall();
		items[startCol + 5][startRow + 1] = new Wall();
		items[startCol + 5][startRow + 3] = new Wall();
	}

}
