import greenfoot.GreenfootImage;

/**
 * Representation of the level selection level.
 * 
 * Task: select the next level
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class LevelSelection extends Level {

	public LevelSelection() {
		super("levelS.png", null);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Level#createLevel(Item[][])
	 */
	@Override
	public void createLevel(Item[][] items) {

		// empty all cells
		for (int c = 0; c < items.length; c++) {
			for (int r = 0; r < items[c].length; r++) {
				items[c][r] = null;
			}
		}

		// place walls
		for (int r = 0; r < Level.LEVELS; r++) {
			for (int c = 1; c < 8; c++) {
				items[c][r * 2 + 1] = new Wall();
			}
		}
		items[0][Level.LEVELS * 2 - 1] = new Wall();

		// place the selection items of each level
		for (int l = 0; l < Level.LEVELS; l++) {
			items[6][l * 2] = Level.getLevel(l + 1).getSelectionItem();
			items[7][l * 2] = new Wall();
		}

		// place grass

		for (int c = 9; c < items.length; c += 2) {
			for (int r = 0; r < items[c].length; r++) {
				items[c - (r % 2)][r] = new Grass();
			}
		}
		for (int r = 2 * Level.LEVELS; r < items[0].length; r++) {
			for (int c = 1; c < 8; c += 2) {
				items[c - (r % 2)][r] = new Grass();
			}
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Level#getSeconds()
	 */
	@Override
	public int getSeconds() {
		return 60;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Level#drawHelp(greenfoot.GreenfootImage)
	 */
	@Override
	public void drawHelp(GreenfootImage image) {
		image.drawString("Selection Level: ", 20, 50);
		image.drawString("Task: Select a level!", 20, 100);
	}

}
