import greenfoot.GreenfootImage;

/**
 * Representation of a nuclear power station. By entering a nuclear power
 * station it will be replaced by a windmill.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Nuclear extends Item {

	final static int BONUS = 30; // bonus points for replacing a nuclear power
	// station by a windmill.

	final static int TIMER = 400;

	// shared by all objects
	private static GreenfootImage img = new GreenfootImage("nuclear.png");

	private int number;

	public Nuclear() {
		super(Item.NUCLEAR_WIND);
		this.number = 0;
		this.setImage(Nuclear.img);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		return true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c + 1) * cellSize, (r + 1) * cellSize);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#handleCollisionAfterScrolling(WasteWorld, int, int)
	 */
	@Override
	public void handleCollisionAfterScrolling(WasteWorld world, int col, int row) {
		Boy boy = world.getBoy();
		world.changeItem(col, row, new Windmill()); // remove nuclear power
		// station, put windmill
		Sounds.conservationBonus();
		ConservationBonus bonus = new ConservationBonus(Nuclear.BONUS);
		world.addObject(bonus, boy.getX(), boy.getY()
				- boy.getImage().getHeight());
		Points.getPoints().incrPoints(Nuclear.BONUS);
		world.repaint();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#act(WasteWorld, int, int)
	 */
	@Override
	public void act(WasteWorld world, int col, int row) {
		this.number++;
		if (this.number == Nuclear.TIMER) {
			// new radioactivity
			Position pos = world.getFreeCell();
			world.checkAndChangeItem(pos.getCol(), pos.getRow(),
					new Radioactivity());
			this.number = 0;
		}
	}
}
