import greenfoot.GreenfootImage;

/**
 * Representation of a one-way-sign.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class OneWay extends Item {

	// shared by all objects
	private static GreenfootImage leftImg = new GreenfootImage(
			"oneway-left.png");
	private static GreenfootImage rightImg = new GreenfootImage(
			"oneway-right.png");

	private boolean isLeft; // left or right?

	public OneWay() {
		this(true);
	}

	public OneWay(boolean left) {
		this.isLeft = left;
		if (left) {
			this.setImage(OneWay.leftImg);
		} else {
			this.setImage(OneWay.rightImg);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		Boy boy = world.getBoy();
		// only one-way
		if (this.isLeft) {
			return boy.getCol() == col + 1;
		} else {
			return boy.getCol() == col - 1;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c + 1) * cellSize, r * cellSize);
	}
}
