import greenfoot.Greenfoot;
import greenfoot.GreenfootImage;

/**
 * Representation of a pitfall. By entering a pitfall the boy will be put in the
 * upper left corner of the world. A pitfall can be passed with the help of a
 * ladder.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Pitfall extends Item {

	// shared by all objects
	private static GreenfootImage img = new GreenfootImage("pitfall.png");

	public Pitfall() {
		super(Item.PITFALL_LADDER);
		this.setImage(Pitfall.img);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		return true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c + 1) * cellSize, (r + 1) * cellSize);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#handleCollisionAfterScrolling(WasteWorld, int, int)
	 */
	@Override
	public void handleCollisionAfterScrolling(WasteWorld world, int col, int row) {
		Item ladder = Storage.getStorage().removeOneItem(this.getType());
		if (ladder == null) {
			Sounds.beam(); // the boy falls into the pitfall
			Greenfoot.delay(5);
			world.getBoy().reset(0, 0, Boy.DOWN);
		} else {
			Sounds.putThing(); // put down the ladder; now the boy can pass the
			// ladder
			world
					.changeItem(col, row, new PitfallLadder(this,
							(Ladder) ladder));
		}
	}
}
