import greenfoot.Actor;
import greenfoot.GreenfootImage;

import java.awt.Color;
import java.awt.Font;

/**
 * representation of the points (singleton pattern)
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Points extends Actor {
	private int points;

	private static Points p = new Points();

	public static Points getPoints() {
		return Points.p;
	}

	private GreenfootImage image, pointsImage;

	private Points() { // singleton
		this.points = 0;
		this.pointsImage = new GreenfootImage("points.png");
		this.image = new GreenfootImage("points.png");
		this.image.setTransparency(200);
		this.image.setColor(Color.black);
		this.image.setFont(new Font("Monospaced", Font.BOLD, 36));
		this.updateImage();
		this.setImage(this.image);
	}

	public void setPoints(int n) {
		this.points = n;
		this.updateImage();
	}

	public void incrPoints(int n) {
		this.points += n;
		this.updateImage();
	}

	public void clear() {
		this.points = 0;
		this.updateImage();
	}

	public void decrPoints(int n) {
		this.points -= n;
		this.updateImage();
	}

	public int getPointsNumber() {
		return this.points;
	}

	private void updateImage() {
		this.image.clear();
		this.image.drawImage(this.pointsImage, 0, 0);
		String str = "" + this.points;
		int slen = Metrics.stringWidth(str, this.image.getFont());
		this.image.drawString(str, this.image.getWidth() / 2 - slen / 2, 35);
	}
}
