import greenfoot.GreenfootImage;

/**
 * Representation of a selection item. It is used in the selection level.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class SelectionItem extends Item {

	private boolean hasBeenSelected;
	private int number;

	public SelectionItem(int n, String image) {
		super();
		this.number = n;
		this.hasBeenSelected = false;
		this.setImage(image);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		return !this.hasBeenSelected; // a level can only be entered once
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c - 4) * cellSize, r * cellSize);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#handleCollisionAfterScrolling(WasteWorld, int, int)
	 */
	@Override
	public void handleCollisionAfterScrolling(WasteWorld world, int col, int row) {
		if (!this.hasBeenSelected) {
			Sounds.select();
			this.hasBeenSelected = true;
			this.getImage().setTransparency(50);
			world.setSelectedLevel(Level.createAndGetLevel(this.number, world
					.getItems()));
		}
	}
}
