import greenfoot.GreenfootImage;

/**
 * Representation of a street lamp. By entering a street lamp the lamp will be
 * switched off.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Streetlamp extends Item {
	final static int BONUS = 20; // bonus points for switching off a lamp

	// shared by all lamps
	final static GreenfootImage imageOn = new GreenfootImage(
			"streetlamp-on.png");
	final static GreenfootImage imageOff = new GreenfootImage(
			"streetlamp-off.png");

	private boolean isOn;

	public Streetlamp() {
		this.setImage(Streetlamp.imageOn);
		this.isOn = true;
	}

	public void switchOff() {
		this.setImage(Streetlamp.imageOff);
		this.isOn = false;
	}

	public void switchOn() {
		this.setImage(Streetlamp.imageOn);
		this.isOn = true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		return true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c + 1) * cellSize, r * cellSize);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#handleCollisionAfterScrolling(WasteWorld, int, int)
	 */
	@Override
	public void handleCollisionAfterScrolling(WasteWorld world, int col, int row) {
		if (this.isOn) {
			this.switchOff();
			Boy boy = world.getBoy();
			Sounds.conservationBonus();
			if (world.getLevel().getWorldFilter() != null) {
				// reduce the brightness
				world.getLevel().getWorldFilter().reduceTransparency();
			}
			ConservationBonus bonus = new ConservationBonus(Streetlamp.BONUS);
			world.addObject(bonus, boy.getX(), boy.getY()
					- boy.getImage().getHeight());
			Points.getPoints().incrPoints(Streetlamp.BONUS);
			world.repaint();
		}
	}
}
