import greenfoot.GreenfootImage;

/**
 * Representation of a tree stump. Can be replaced by a new tree.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class Stump extends Item {

	final static int BONUS = 30; // bonus points for replacing a tree stump by a
	// new tree

	// shared by all objects
	private static GreenfootImage img = new GreenfootImage("stump.png");

	public Stump() {
		super(Item.STUMP_TREE);
		this.setImage(Stump.img);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		return true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c + 1) * cellSize, (r + 1) * cellSize);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#handleCollisionAfterScrolling(WasteWorld, int, int)
	 */
	@Override
	public void handleCollisionAfterScrolling(WasteWorld world, int col, int row) {
		Boy boy = world.getBoy();
		world.changeItem(col, row, new NewTree()); // remove stump, put tree
		Sounds.conservationBonus();
		ConservationBonus bonus = new ConservationBonus(Stump.BONUS);
		world.addObject(bonus, boy.getX(), boy.getY()
				- boy.getImage().getHeight());
		Points.getPoints().incrPoints(Stump.BONUS);
		world.repaint();
	}
}
