import greenfoot.GreenfootImage;

/**
 * Representation of a traffic light. Can only be passed if the light is green.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class TrafficLight extends Item {

	// shared by all lamps
	final static GreenfootImage imageRed = new GreenfootImage(
			"trafficlight-red.png");
	final static GreenfootImage imageGreen = new GreenfootImage(
			"trafficlight-green.png");

	final static int MAX_NUMBER = 60;
	private int number;
	private boolean isRed;

	public TrafficLight() {
		this.setImage(TrafficLight.imageRed);
		this.isRed = true;
		this.number = 0;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#act(WasteWorld, int, int)
	 */
	@Override
	public void act(WasteWorld world, int col, int row) {
		// switch the light on and off
		this.number++;
		if (this.number >= TrafficLight.MAX_NUMBER) {
			this.switchLamps();
			this.number = 0;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		return !this.isRed; // only if the light is green
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c + 1) * cellSize, r * cellSize);
	}

	void toRed() {
		this.setImage(TrafficLight.imageRed);
		this.isRed = true;
	}

	void toGreen() {
		this.setImage(TrafficLight.imageGreen);
		this.isRed = false;
	}

	void switchLamps() {
		if (this.isRed) {
			this.toGreen();
		} else {
			this.toRed();
		}
	}

}
