import greenfoot.GreenfootImage;

/**
 * Representation of a water-tap. By entering a water-tap the tap will be turned
 * off.
 * 
 * @author Dietrich Boles (University of Oldenburg, Germany)
 * @version 01.12.2009
 */
public class WaterTap extends Item {
	final static int BONUS = 20; // bonus points for turning off a tap

	// shared by all objects
	private static GreenfootImage[] images;

	static {
		WaterTap.images = new GreenfootImage[5];
		WaterTap.images[0] = new GreenfootImage("tap-on0.png");
		WaterTap.images[1] = new GreenfootImage("tap-on1.png");
		WaterTap.images[2] = new GreenfootImage("tap-on2.png");
		WaterTap.images[3] = new GreenfootImage("tap-on3.png");
		WaterTap.images[4] = new GreenfootImage("tap-off.png");
	}

	private boolean isOn;
	private int number;

	public WaterTap() {
		this.number = 0;
		this.setImage(WaterTap.images[this.number]);
		this.isOn = true;
	}

	public void turnOff() {
		this.setImage(WaterTap.images[WaterTap.images.length - 1]);
		this.isOn = false;
	}

	public void turnOn() {
		this.setImage(WaterTap.images[0]);
		this.isOn = true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#act(WasteWorld, int, int)
	 */
	@Override
	public void act(WasteWorld wasteWorld, int col, int row) {
		if (this.isOn) {
			this.number = (this.number + 1) % (WaterTap.images.length - 1);
			this.setImage(WaterTap.images[this.number]);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#isAccessible(WasteWorld, int, int)
	 */
	@Override
	public boolean isAccessible(WasteWorld world, int col, int row) {
		return true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#draw(greenfoot.GreenfootImage, int, int, int)
	 */
	@Override
	public void draw(GreenfootImage img, int c, int r, int cellSize) {
		img.drawImage(this.getImage(), (c + 1) * cellSize, (r + 1) * cellSize);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see Item#handleCollision(WasteWorld, int, int)
	 */
	@Override
	public void handleCollision(WasteWorld world, int col, int row) {
		if (this.isOn) {
			this.turnOff();
			Boy boy = world.getBoy();
			Sounds.conservationBonus();
			if (world.getLevel().getCellFilter() != null) {
				// reduce the blue filter
				world.getLevel().getCellFilter().reduceTransparency();
			}
			ConservationBonus bonus = new ConservationBonus(WaterTap.BONUS);
			world.addObject(bonus, boy.getX(), boy.getY()
					- boy.getImage().getHeight());
			Points.getPoints().incrPoints(WaterTap.BONUS);
			world.repaint();
		}
	}
}
